==> haskell-httpd-shed-0.4.1.2-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 httpd-shed
version:              0.4.1.2
visibility:           public
id:                   httpd-shed-0.4.1.2-JmX21fgA68K4Yrj5fVWllX
key:                  httpd-shed-0.4.1.2-JmX21fgA68K4Yrj5fVWllX
license:              BSD-3-Clause
copyright:            (c) 2009 Andy Gill
maintainer:           Ganesh Sittampalam
author:               Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis:             A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.

category:             Network, Web
abi:                  1c81d2aee31306c1ee630266677f886c
exposed:              True
exposed-modules:      Network.Shed.Httpd
import-dirs:          /usr/lib/ghc-9.4.8/site-local/httpd-shed-0.4.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/httpd-shed-0.4.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/httpd-shed-0.4.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-httpd-shed
hs-libraries:         HShttpd-shed-0.4.1.2-JmX21fgA68K4Yrj5fVWllX
depends:
    base-4.17.2.1 network-3.1.4.0-29qUxJkoDip75hxElAm7gZ
    network-bsd-2.8.1.0-IAS1qur8JZX3uytFIM29lY
    network-uri-2.6.4.2-2Sr7Eg9Bhz3KcJ8Mdx9CYP

haddock-interfaces:   /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html:         /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-httpd-shed-0.4.1.2-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 httpd-shed
version:              0.4.1.2
visibility:           public
id:                   httpd-shed-0.4.1.2-4N8osY7mx2V7gTfMXJYt7I
key:                  httpd-shed-0.4.1.2-4N8osY7mx2V7gTfMXJYt7I
license:              BSD-3-Clause
copyright:            (c) 2009 Andy Gill
maintainer:           Ganesh Sittampalam
author:               Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis:             A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.

category:             Network, Web
abi:                  dbd434c843192c925f68fd21c756ac12
exposed:              True
exposed-modules:      Network.Shed.Httpd
import-dirs:          /usr/lib/ghc-9.4.8/site-local/httpd-shed-0.4.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/httpd-shed-0.4.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/httpd-shed-0.4.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-httpd-shed
hs-libraries:         HShttpd-shed-0.4.1.2-4N8osY7mx2V7gTfMXJYt7I
depends:
    base-4.17.2.1 network-3.1.4.0-6CSLlS2XYBeLlFfm0MgCfu
    network-bsd-2.8.1.0-2HIgC0sZxzLBDkAcijwyGk
    network-uri-2.6.4.2-APaQU0Ye6OaKm6pWDY2rCG

haddock-interfaces:   /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html:         /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
